@@ -1,13 +1,10 @@
 """Nornir F5 Automation Toolchain (ATC) tasks.
 
 Allows to deploy F5 ATC declarations (AS3, DO, TS) on BIG-IP systems.
-
-Todo:
-    * Telemetry
 """
-
 import json
 import time
+from typing import Optional
 from urllib.parse import urlencode
 
 from nornir.core.task import Result, Task
@@ -104,9 +101,9 @@ def _build_as3_endpoint(
 def _send(
     task: Task,
     atc_config_endpoint: str,
+    atc_declaration: str,
     atc_method: str,
     atc_service: str,
-    atc_declaration: str,
 ) -> Result:
     client = f5_rest_client(task)
     host = f"{task.host.hostname}:{task.host.port}"
@@ -175,18 +172,55 @@ def _wait_task(
     raise Exception("The task has reached maximum retries.")
 
 
+def atc_info(task: Task, atc_method: str, atc_service: str) -> Result:
+    """Task to verify if ATC service is available and collect service info.
+
+    Args:
+        task (Task): The Nornir task.
+        atc_method (str): The HTTP method. Accepted values include [POST, GET]
+            for all services, and [DELETE] for AS3.
+        atc_service (str): The ATC service.
+            Accepted values include [AS3, Device, Telemetry].
+
+    Returns:
+        Result: The result.
+
+    Raises:
+        Exception: The raised exception when the task had an error.
+    """
+    client = f5_rest_client(task)
+    host = f"{task.host.hostname}:{task.host.port}"
+
+    # Validate ATC service
+    if atc_service not in ATC_SERVICE_OPTIONS:
+        raise Exception(f"ATC service '{atc_service}' is not valid.")
+
+    # Validate ATC method
+    atc_methods = ATC_COMPONENTS[atc_service]["endpoints"]["configure"]["methods"]
+    if atc_method not in atc_methods:
+        raise Exception(f"ATC method '{atc_method}' is not valid.")
+
+    return Result(
+        host=task.host,
+        result=client.get(
+            f"https://{host}{ATC_COMPONENTS[atc_service]['endpoints']['info']['uri']}"
+        ).json(),
+    )
+
+
 def atc(
     task: Task,
     as3_show: str = "base",
     as3_show_hash: bool = False,
-    as3_tenant: str = "",
-    atc_declaration: str = "",
-    atc_declaration_file: str = "",
-    atc_declaration_url: str = "",
+    as3_tenant: Optional[str] = None,
+    atc_declaration: Optional[str] = None,
+    atc_declaration_file: Optional[str] = None,
+    atc_declaration_url: Optional[str] = None,
     atc_delay: int = 30,
     atc_method: str = "GET",
     atc_retries: int = 10,
-    atc_service: str = "",
+    atc_service: Optional[str] = None,
+    dry_run: Optional[bool] = None,
 ) -> Result:
     """Task to deploy declaratives on F5 devices.
 
@@ -202,29 +236,27 @@ def atc(
         as3_show_hash (bool): The AS3 `showHash` value that is used as protection
             mechanism for tenants in a declaration. If set to `True`, the result returns
             an `optimisticLockKey` for each tenant.
-        as3_tenant: The AS3 tenant filter. This only updates the tenant specified,
-            even if there are other tenants in the declaration.
-        atc_declaration (str): The ATC declaration.
+        as3_tenant (Optional[str]): The AS3 tenant filter. This only updates the tenant
+            specified, even if there are other tenants in the declaration.
+        atc_declaration (Optional[str]): The ATC declaration.
             Mutually exclusive with `atc_declaration_file` and `atc_declaration_url`.
-        atc_declaration_file (str): The path of the ATC declaration.
+        atc_declaration_file (Optional[str]): The path of the ATC declaration.
             Mutually exclusive with `atc_declaration` and `atc_declaration_url`.
-        atc_declaration_url (str): The URL of the ATC declaration.
+        atc_declaration_url (Optional[str]): The URL of the ATC declaration.
             Mutually exclusive with `atc_declaration` and `atc_declaration_file`.
         atc_delay (int): The delay (in seconds) between retries
             when checking if async call is complete.
         atc_method (str): The HTTP method. Accepted values include [POST, GET]
             for all services, and [DELETE] for AS3.
-        atc_retries (int): The number of times the task will check for a finished task
-            before failing.
-        atc_service (str): The ATC service.
+        atc_retries (int): The number of times the task will check
+            for a finished task before failing.
+        atc_service (Optional[str]): The ATC service.
             Accepted values include [AS3, Device, Telemetry].
             If not provided, this will auto select from the declaration.
+        dry_run (Optional[bool]): Whether to apply changes or not.
 
     Returns:
         Result: The result.
-
-    Raises:
-        Exception: The raised exception when the task had an error.
     """
     # Get ATC declaration from file
     if atc_declaration_file:
@@ -237,24 +269,14 @@ def atc(
     # Get ATC service from declaration
     if atc_declaration and not atc_service:
         atc_service = atc_declaration["class"]
-    # Validate ATC service
-    if atc_service not in ATC_SERVICE_OPTIONS:
-        raise Exception(f"ATC service '{atc_service}' is not valid.")
 
-    # Validate ATC method
-    atc_methods = ATC_COMPONENTS[atc_service]["endpoints"]["configure"]["methods"]
-    if atc_method not in atc_methods:
-        raise Exception(f"ATC method '{atc_method}' is not valid.")
-
-    # Set host
-    host = f"{task.host.hostname}:{task.host.port}"
-
-    # Verify ATC service is available, and collect service info
-    atc_service_info = (
-        f5_rest_client(task)
-        .get(f"https://{host}{ATC_COMPONENTS[atc_service]['endpoints']['info']['uri']}")
-        .json()
-    )
+    # Get service info
+    atc_service_info = task.run(
+        name="Get ATC info",
+        task=atc_info,
+        atc_method=atc_method,
+        atc_service=atc_service,
+    ).result
 
     # Set ATC config endpoint
     atc_config_endpoint = ATC_COMPONENTS[atc_service]["endpoints"]["configure"]["uri"]
@@ -262,14 +284,18 @@ def atc(
     # Build AS3 endpoint
     if atc_service == "AS3":
         atc_config_endpoint = _build_as3_endpoint(
-            as3_tenant=as3_tenant,
-            as3_version=atc_service_info["version"],
             as3_show=as3_show,
             as3_show_hash=as3_show_hash,
+            as3_tenant=as3_tenant,
+            as3_version=atc_service_info["version"],
             atc_config_endpoint=atc_config_endpoint,
             atc_method=atc_method,
         )
 
+    dry_run = task.is_dry_run(dry_run)
+    if dry_run:
+        return Result(host=task.host, result=None)
+
     # Send the declaration
     atc_send_result = task.run(
         name=f"{atc_method} the declaration",
